Type: Package
Package: magrittr
Title: A Forward-Pipe Operator for R
Version: 2.0.5
Authors@R: c(
    person("Stefan Milton", "Bache", , "stefan@stefanbache.dk", role = c("aut", "cph"),
           comment = "Original author and creator of magrittr"),
    person("Hadley", "Wickham", , "hadley@posit.co", role = "aut"),
    person("Lionel", "Henry", , "lionel@posit.co", role = "cre"),
    person("Posit Software, PBC", role = c("cph", "fnd"),
            comment = c(ROR = "03wc8by49"))
  )
Description: Provides a mechanism for chaining commands with a new
    forward-pipe operator, %>%. This operator will forward a value, or the
    result of an expression, into the next function call/expression.
    There is flexible support for the type of right-hand side expressions.
    For more information, see package vignette.  To quote Rene Magritte,
    "Ceci n'est pas un pipe."
License: MIT + file LICENSE
URL: https://magrittr.tidyverse.org,
        https://github.com/tidyverse/magrittr
BugReports: https://github.com/tidyverse/magrittr/issues
Depends: R (>= 3.4.0)
Suggests: covr, knitr, rlang, rmarkdown, testthat
VignetteBuilder: knitr
ByteCompile: Yes
Config/Needs/website: tidyverse/tidytemplate
Encoding: UTF-8
RoxygenNote: 7.3.3
NeedsCompilation: yes
Packaged: 2026-04-03 08:09:48 UTC; lionel
Author: Stefan Milton Bache [aut, cph] (Original author and creator of
    magrittr),
  Hadley Wickham [aut],
  Lionel Henry [cre],
  Posit Software, PBC [cph, fnd] (ROR: <https://ror.org/03wc8by49>)
Maintainer: Lionel Henry <lionel@posit.co>
Repository: CRAN
Date/Publication: 2026-04-04 08:00:02 UTC
Built: R 4.5.2; aarch64-apple-darwin20; 2026-04-04 10:13:02 UTC; unix
Archs: magrittr.so.dSYM
